#include "netbsd.h"

#define netbsd1 1 /* we're really close to this */

#undef MBPOOL_SYMBOL
#undef MCLPOOL_SYMBOL
